summaryrefslogtreecommitdiff
path: root/src/lib/player_video.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/player_video.h')
-rw-r--r--src/lib/player_video.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/lib/player_video.h b/src/lib/player_video.h
index f2781c1a0..10b2078a0 100644
--- a/src/lib/player_video.h
+++ b/src/lib/player_video.h
@@ -59,7 +59,7 @@ public:
boost::optional<ColourConversion> colour_conversion,
VideoRange video_range,
std::weak_ptr<Content> content,
- boost::optional<Frame> video_frame,
+ boost::optional<dcpomatic::ContentTime> video_time,
bool error
);
@@ -141,8 +141,8 @@ private:
boost::optional<PositionImage> _text;
/** Content that we came from. This is so that reset_metadata() can work. */
std::weak_ptr<Content> _content;
- /** Video frame that we came from. Again, this is for reset_metadata() */
- boost::optional<Frame> _video_frame;
+ /** Video time that we came from. Again, this is for reset_metadata() */
+ boost::optional<dcpomatic::ContentTime> _video_time;
mutable boost::mutex _mutex;
mutable std::shared_ptr<Image> _image;